@@ -3,7 +3,7 @@
 # Nov 2018
 
 from bfit.fitting.global_fitter import global_fitter
-from bdata import bdata
+import bdata as bd
 import numpy as np
 import collections
 
@@ -11,50 +11,56 @@ import collections
 class global_bdata_fitter(global_fitter):
     
     # ======================================================================= #
-    def __init__(self,runs,years,fn,sharelist,npar=-1,xlims=None,rebin=1):
+    def __init__(self,data,fn,shared,xlims=None,rebin=1,asym_mode='c',fixed=None):
         """
-            runs:       list of run numbers
-            
-            years:      list of years corresponding to run numbers, or int which applies to all
+            data:       list of bdata objects
             
             fn:         list of function handles to fit (or single which applies to all)
                         must specify inputs explicitly (do not do def fn(*par)!)
                         must have len(fn) = len(runs) if list
                         
-            sharelist:  list of bool to indicate which parameters are shared. 
+            shared:     list of bool to indicate which parameters are shared. 
                         True if shared
                         len = number of parameters.
                         
-            npar:       number of free parameters in each fitting function.
-                        Set if number of parameters is not intuitable from 
-                            function code.            
-            
             xlims:      list of 2-tuples for (low,high) bounds on fitting range 
                             based on x values. If list is not depth 2, use this 
                             range on all runs.
             
             rebin:      rebinning factor on fitting and drawing data
+            
+            fixed:      list of booleans indicating if the paramter is to be 
+                        fixed to p0 value (same length as p0). Returns best 
+                        parameters in order presented, with the fixed 
+                        parameters omitted.
+            
+            asym_mode:  asymmetry type to calculate and fit
         """
         
-        # Set years
-        if not isinstance(years,collections.Iterable):
-            years = [years]*len(runs)
+        # check input type
+        if type(data) in (bd.bdata,bd.bjoined):
+            data = [data]
+        ndata = len(data)
+        
+        # Set rebin
+        if not isinstance(rebin,collections.Iterable):
+            rebin = [rebin]*ndata
         
         # Get asymmetry
-        data = [bdata(r,year=y).asym('c',rebin=rebin) for r,y in zip(runs,years)]
+        asym = np.asarray([d.asym(asym_mode,rebin=re) for d,re in zip(data,rebin)])
         
         # split into x,y,dy data sets
-        x = np.array([d[0] for d in data])
-        y = np.array([d[1] for d in data])
-        dy = np.array([d[2] for d in data])
+        x = asym[:,0]
+        y = asym[:,1]
+        dy = asym[:,2]
         
         # select subrange
         if xlims is not None:
             
             # check depth
             if len(np.array(xlims).shape) < 2:
-                xlims = [xlims for i in range(len(x))]
-            
+                xlims = [xlims]*ndata
+                            
             # initialize new inputs
             xnew = []
             ynew = []
@@ -73,4 +79,4 @@ class global_bdata_fitter(global_fitter):
             dy = np.array(dynew)
             
         # intialize
-        super(global_bdata_fitter,self).__init__(x,y,dy,fn,sharelist,npar)
+        super(global_bdata_fitter,self).__init__(x,y,dy,fn,shared,fixed)
